#
# spec file for package ceph-deploy
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
%if 0%{?fedora}
  %bcond_without unit_tests
%endif
%if 0%{?rhel}
  %bcond_with unit_tests
%endif
%if 0%{?suse_version}
  %if 0%{?is_opensuse}
    %bcond_without unit_tests    
  %else
    %bcond_with unit_tests
  %endif
%endif


%if ! (0%{?fedora} > 12 || 0%{?rhel} > 5)
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%endif

Name:           ceph-deploy
Version:        1.5.38+git.1499740004.c6666bf
Release:        1.1
Summary:        Admin and deploy tool for Ceph
License:        MIT
Group:          System/Filesystems
Url:            https://github.com/ceph/ceph-deploy
Source0:        %{name}-%{version}.tar.xz
# remoto is from git://ceph.com/remoto, see note in prep section

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-mock >= 1.0b1
BuildRequires:  python-remoto >= 0.0.27
BuildRequires:  python-setuptools
BuildRequires:  python-argparse
%if 0%{with unit_tests}
BuildRequires:  python-tox >= 1.2
BuildRequires:  python-virtualenv
BuildRequires:  python-pip
BuildRequires:  python-flake8
%if 0%{?suse_version}
BuildRequires:  python-pytest >= 2.1.3
%else
BuildRequires:  pytest
%endif
%endif
Requires:       python-argparse
Requires:       python-remoto >= 0.0.27
Requires:	    python-setuptools

%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif
%if 0%{?suse_version}
%if 0%{?suse_version} > 1210
Requires:       gptfdisk
%else
Requires:       scsirastools
%endif
%else
Requires:       gdisk
%endif

%description
An easy to use admin tool for deploy ceph storage clusters.

%prep
%setup -q

# setup.py normally pulls down the remoto source using git.
# Pre-populate the directory so that this step is avoided.
%setup -q -T -D -n %{name}-%{version}

%build
# force no new version of remoto
CEPH_DEPLOY_NO_VENDOR=no python setup.py build

%install
# force no new version of remoto
CEPH_DEPLOY_NO_VENDOR=no python setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -m 0755 -D scripts/ceph-deploy %{buildroot}%{_bindir}

%check
%if 0%{with unit_tests}
# Call the unit tests directly as OBS blocks internet connection for builds
# python setup.py test
py.test ceph_deploy/tests/test_gather_keys*.py
py.test ceph_deploy/tests/test_install.py
py.test ceph_deploy/tests/test_keys_equivalent.py
py.test ceph_deploy/tests/test_mon.py
py.test ceph_deploy/tests/test_remotes.py
py.test ceph_deploy/tests/unit/
CEPH_DEPLOY_NO_VENDOR=no flake8 --select=F,E9 ceph_deploy
%endif

%files
%defattr(-,root,root,-)
%doc LICENSE README.rst
%{_bindir}/ceph-deploy
%{python_sitelib}/*

%changelog
* Tue Jul 11 2017 tserong@suse.com
- Updated to 1.5.38
  + Allow unsigned deb packages from mirrors
  + Detect systemd before sysvinit in centos
  + Fix UnboundLocalError when installing in debian with custom repo flags
  + gatherkeys to give mgr "allow * " permissions
  + specify block.db and block.wal for bluestore
  + be able to install ceph-mgr
  + bootstrap mgr keys
  + cleanup mds key creation
  + Virtuozzo Linux support
  + update osd and mds caps
  + Use the ``--cluster`` flag on monitor commands (defaulting to 'ceph' if
    unspecfied)
  + After adding a monitor, ensure it is started regardless of init system
  + Allow Oracle Linux Server to be deployed to.
  + Fix issue when calling gatherkeys where a log argument was missing
  + Use the new development services for installation (from chacra.ceph.com and
    shaman.ceph.com URLs)
  + Try to decode bytes only on Python 3 when writing files on remote hosts
* Thu Nov 24 2016 osynge@suse.com
- Added flake8 to rpm check
- Added most unit tests to rpm check
- Remove dependancy on python-pushy
- Updated to 1.5.36
    + Prefer to use ``load_raw`` to avoid mangling ceph.conf content.
    + Improve systemd/sysvinit detection for both CentOS and RHEL
    + Gatherkeys should try to get an existing key without caps, in case they don't
    match
    + Add compatibility for bytes/strings with Python 3
    + Fix errors in argparse default behavior (error messages, incomplete commands)
    + Add Python 3.4 to tox
    + Python 3 changes to workaround configparser issues
    + Use the configured username when using rsync to a remote host (local repo
    support)
    + Install Python 3 with the bootstrap sciprt
    + Bump remoto requirement to 0.0.29
    + Include admin.rst and gatherkeys.rst in the TOC index
    + Handle Ceph package split in Ubuntu
    + Add a ``--nogpgcheck`` option to disable checks on local repos
    + Improve sysvinit/systemd checks by not including 'ceph' in the path
    + Install Diamond when calling ``ceph-deploy calamari connect``
    + Zypper fixes for purging: allows removal of multiple packages
* Tue Aug  9 2016 osynge@suse.com
- Updated to 1.5.34
  + Do not call partx/partprobe when zapping disks
  + No longer allow using ext4
  + Default to systemd for SUSE
  + Remove usage of rcceph (for SUSE)
  + No longer depend on automatic ``ceph-create-keys``, use the monitors to
    fetch keys.
- Protect against two rgw using the same port.
  + bnc#980708
* Tue May 24 2016 osynge@suse.com
- gatherkeys subcommand to handle long hostnames.
  + bnc#981304
* Thu May 19 2016 osynge@suse.com
- rgw help now works on SLE12 as well as LEAP.
  + bnc#980704
* Wed May 18 2016 osynge@suse.com
- Revert previous fix to bnc#980273 and apply better fix.
* Wed May 18 2016 osynge@suse.com
- loosen restrictions on rgw names
* Wed May 18 2016 osynge@suse.com
- ceph-deploy purge no longer aborts if one package is not installed
  + bnc#980273
- Install RadosGW with non valid chanacters trapped early
  + bnc#976395
* Fri May 13 2016 osynge@suse.com
- Added rgw port options
  + bnc#979872
- Add warning if deploying a rgw twice
  + bnc#970526
* Wed May  4 2016 osynge@suse.com
- Added rgw delete to online help.
  + bnc#978432
* Thu Apr 14 2016 osynge@suse.com
- Updated to 1.5.32
  + Bluestore support
  + Disable timeouts for pkg install/remove operations (they can take a long
    time)
  + Remove deprecated ceph.conf configuration "filestore xattr use omap = true"
* Tue Apr 12 2016 osynge@suse.com
- Gather keys directly from mon rather than file system
  + Added test case for Gather keys directly from mon
- Added BuildRequires on python-argparse python-pip
* Fri Apr  1 2016 osynge@suse.com
- Add rgw list function
- Add rgw delete function
* Fri Apr  1 2016 CET 2016 - osynge@suse.com
- Dont rely on ceph systemd files to create keys on mon booting.
  + This can casue an issue when installing older versions of ceph.
- ceph_deploy.rgw: Add config file options
  + bnc#970526
- calamari without salt minion repo
* Mon Feb 29 2016 CET 2016 - osynge@suse.com
- zypper handle ZYPPER_EXIT_INF_CAP_NOT_FOUND return code
  + bnc#968123
- ceph no longer packages rcceph
  + RM-14740
- Change default init system for SUSE platforms to systemd.
  + bnc#963022 and RM-14742 Set default init to systemd for (open)SUSE
- Updated to 1.5.31
  + Updated to remoto version 0.0.27
  + Fix an issue when trying to destroy/stop monitors on systemd servers
  + Enable Ceph on ``osd create``
  + Remove bootstrap-rgw key when forgetkeys is used
  + Prefer systemd over upstart in newer Ubuntu
  + Use better examples in default cephdeploy.conf file
  + Cleanup functions for uninstall and purge (simplifying code)
  + Do not udevadm trigger because ceph-disk does it already
  + Specify a PID location for monitors
  + Fix invalid path for release keys in test
  + Add timestamp to log output
  + Support systemd and sysvinit on RHEL, Fedora, and CentOS, when systemd
    is present in the Ceph packages.
  + Simplify steps taken when adding a monitor with ``ceph-deploy mon add``.
    Eliminates a 5-minute hang when moving from 1 monitor to 2.
  + Make sure that Ceph is installed on a remote node before trying to enable
    a Ceph daemon.
  + Ability to install subset of ceph packages based on CLI switches like
    ``--cli``, ``--rgw``, etc.
  + Fixed an issue that prevented package upgrades when using DNF.
  + No longer installs yum-priorities-plugin when using DNF.
  + Make parsing of boolean values in config file overrides work.
  + Output value of all ceph-deploy options upon invocation.
  + Allow ceph-deploy to work on Mint distro.
  + Improved help menu output during subcommand context.
  + Point to SUSE downstream packages by default on SUSE distros since
    ceph.com does not host packages for SUSE anymore.
  + Installing Ceph daemons that will no longer run as root user.
  + Add support for DNF package manager (Fedora >= 22 only).
  + Echo RGW default port number after ``ceph-deploy rgw create``.
  + **CVE-2015-4053**: Make sure that the admin keyring is mode 0600 after being
    pushed with the ``ceph-deploy admin`` command.
  + Improved SUSE install and purge.
  + Make sure that package name 'ceph-radosgw' is used everywhere for RPM systems
    instead of 'radosgw'.
  + Automatically prefix custom RGW daemon names with 'rgw.'
  + Create /var/lib/ceph/radosgw directory on remote host if not present
  + Add flags to support install of specific daemons (OSD, MON, RGW, MDS) only
  + Enable ceph-mds service correctly on systemd
  + Check for sysvinit and custom cluster name on 'ceph-deploy new' command
* Fri Jan 22 2016 osynge@suse.com
- Change default init system for SUSE platforms to systemd.
  + bnc#963022
* Wed Nov 25 2015 osynge@suse.com
- rgw:Add rgw_dns_name to rgw entity in ${CLUSTER}.conf to fix the
  s3 api response.
  + bnc#948577
* Thu Oct  1 2015 osynge@suse.com
- Decreased the number of placement groups for each pool created by
  ceph-deploy for the rgw to 16. fix for bnc#948375
- Fix rgw colon separated passing to pass the tox master test suite.
* Thu Sep 17 2015 osynge@suse.com
- Increase number of placement groups for each pool created by
  ceph-deploy for the rgw to 128.
* Mon Sep 14 2015 osynge@suse.com
- Check port is free when deploying rgw.
  + Fails early if service is already
    listening on desired port.
  + bnc#939710
* Mon Aug 31 2015 osynge@suse.com
- osd commands support "/dev/disk/by-path/".
  + bnc #942274
* Mon Aug 31 2015 osynge@suse.com
- Add support for data encryption at rest.
- Add validation of input for rgw.
* Fri Aug 21 2015 osynge@suse.com
- Install rpms based on newer components system.
  + bnc #938894
- Dont display SLE11 on SLE12 operating systems.
  + bnc #942399
* Fri Aug 21 2015 osynge@suse.com
- mon destroy fix by using ceph_deploy.util.services
  + Add support for systemd and remove exception
  + bnc#942495
* Wed Aug 19 2015 osynge@suse.com
- rgw:delete:bugfix cleaning up apache config for fcgi rgw.
  + clean up generated files in /etc/apache2/conf.d/
* Tue Aug 18 2015 osynge@suse.com
- rgw: Handle default ports with apache
  + allow rgw to handle working on port 80 when apache also uses
    port 80 as well.
* Wed Aug 12 2015 osynge@suse.com
- systemd ActiveState can take many values
  + Assume all non "active" states are stopped.
* Wed Aug 12 2015 osynge@suse.com
- rgw: Handle ceph not being installed exception.
  + catch exception with misconfigured ${cluster}.conf when
    "ceph osd lspools" fails.
  + bnc #940840
* Mon Aug 10 2015 osynge@suse.com
- rgw: Handle ceph not being installed exception.
  + catch exception with misconfigured ${cluster}.conf when
    "ceph auth list" fails.
  + bnc #940840
* Tue Jul 21 2015 osynge@suse.com
- rgw: Better apache handling with starting/stopping.
  Apache is only used on fcgi based rgw deployments.
  This patch removes confusing errors from the install
  process for apache when it is not needed.
* Mon Jul 20 2015 osynge@suse.com
- RGW Fix for apache2/fcgi deployment's of rgw not listening to
  correct port. bnc #938566
* Fri Jul 17 2015 osynge@suse.com
- by default set port to 7480 for civetweb installs and 80 for apache fcgi.
  bnc #938565
* Fri Jul 17 2015 osynge@suse.com
- fix cosmetic apache error with ceph-deploy rgw using civetweb
  bnc #938564
* Fri Jul 17 2015 osynge@suse.com
- Fixed bug in rgw code with permissions for logging causing rgw to
  fail.
* Mon Jul 13 2015 osynge@suse.com
- Fix: install method where removing code for changing repos
- Fix rgw: apache2-mod_fastcgi no longer a dependency.
  + as you can use civetweb instead
* Mon Jul 13 2015 osynge@suse.com
- Updated to ceph-deploy ceph-deploy-1.5.25
  + Improved SUSE install and purge.
  + Make sure that package name 'ceph-radosgw' is used everywhere for
    RPM systems instead of 'radosgw'.
  + Use version 0.0.25 of remoto that fixes an issue where output
    would be cut.
* Mon Jun  1 2015 osynge@suse.com
- CVE-2015-4053:
  + ceph-deploy admin command copies keyring file to /etc/ceph which
    is world readable
  + bnc#933028
  + Cherrypicked fixes from https://github.com/ceph/ceph-deploy/pull/300/
* Thu May 14 2015 osynge@suse.com
- change package name to correct name ceph-radosgw
  + rename rpm radosgw to ceph-radosgw
* Tue May 12 2015 ncutler@suse.com
- Modify _service file to implement new version numbering scheme
  + bnc#929553
* Thu May  7 2015 osynge@suse.com
- Remove repository manipulation for hammer
  + SUSE policy is that ceph-deploy should not modify zypper
    repositories
  + d8e5efed251118a8e1f583696de97ce2e9b8829d
* Wed Apr 22 2015 osynge@suse.com
- Updated to 1.5.23
  + Default to Hammer on install.
  + Add ``rgw`` command to easily create rgw instances.
  + Automatically install the radosgw package.
  + Remove unimplemented subcommands from CLI and help.
  +  Fix an issue where keyring permissions were world readable
    (thanks Owen Synge).
  + Fix an issue preventing all but the first host given to
    ``install --repo`` from being used.
- Moved to new packaging system of patches based upon git.
- Changed BuildRequires to python-remoto >= 0.0.23
* Mon Mar  9 2015 osynge@suse.com
- Updated to 1.5.21
* Thu Feb 12 2015 osynge@suse.com
- Support multiple cluster names under systemd.
  + Fixes #915567
  + Initial version does not yet suport rgw.
* Fri Feb  6 2015 osynge@suse.com
- Fixes for SLE11sp3 targets.
  + Fixes #916206 and #916209
  + Modifies patches
  - 05_systemd_use_systemctl.patch
  - 06_Make_host_keys.patch
  - 07_systemd_enable.patch
* Wed Jan 28 2015 osynge@suse.com
- rgw: Added fastcgi copnfig file finder to make cleaning up config files easier.
* Tue Jan 27 2015 osynge@suse.com
- Added rgw parameters and default all values after first paramter.
  + rgw-host     : Host to install the rgw
  + rgw-instance : Ceph instance name [rgw-host]
  + fqdn         : Virtual host to listen [None]
  + port         : Port to listen [80]
  + redirect     : url redirect [^/(.*)]
- Cleaned up logging.
* Tue Jan 27 2015 osynge@suse.com
- Spelling error in rgw help
- Improved "ceph-deploy  rgw list" output.
* Thu Jan 22 2015 osynge@suse.com
- RGW:Enable apache to start on boot
* Wed Jan 21 2015 osynge@suse.com
- Added apache2 config.
  + basic auto generation of /etc/apache2/conf.d/rgw*.conf
  + basic auto generation of /srv/www/radosgw/s3gw*.fcgi
  + Addin missing modules to /etc/sysconfig/apache2
- Removed premature return from zeroing when zapping disks.
* Tue Jan 20 2015 osynge@suse.com
- Added mon allow rwx capabilities to the radowgw key
* Tue Jan 20 2015 osynge@suse.com
- rgw create displays proper error message for invalid hostname
  + Fix for bug #913837
* Mon Jan 19 2015 osynge@suse.com
- rgw : Modified code to remove memoization of host connections.
  + Not suported by remoto
- rgw : Bugfixes to install logic.
  + Added package pkg_refresh
  + Fixed help for rgw
  - bug #913702
* Fri Jan 16 2015 osynge@suse.com
- Updated the initial version of ceph-deploy rgw
  + Changed command line order
  + Added systemd support.
  + Set admin socket correctly.
  + Set logic based.
  + Work in progress, not yet finished.
  + Wroks with names or entities.
* Mon Jan 12 2015 osynge@suse.com
- Added initial version of ceph-deploy rgw
  + in patch 10_add_rgw.patch
  + Work in progress, not yet finished.
* Fri Dec 12 2014 osynge@suse.com
- Remove repository modifying functiosn from ceph-deploy.
  + These include
  - stable
  - release
  - testing
  - dev
  - adjust-repos
  - no-adjust-repos
  - repo
  - repo-url
  - gpg-url
* Thu Dec 11 2014 osynge@suse.com
- run zypper ref before installing ceph with zypper
  + Fix for bug #907518
* Thu Dec  4 2014 lmb@suse.com
- Fix up a few bugzilla references
* Tue Dec  2 2014 osynge@suse.com
- ceph-deploy did not properly adjust monitor start-up (by
  tserong@suse.com, bnc#893810)
* Tue Nov  4 2014 osynge@suse.com
- Improved patch 06_Make_host_keys.patch
  + Now checks if the key does not exist before creating.
  - This makes the code suitable for non SUSE clients.
* Mon Nov  3 2014 osynge@suse.com
- Added patch 06_Make_host_keys.patch
  + This patch makes the host keys for the ceph cluster.
* Sat Nov  1 2014 osynge@suse.com
- Removed 'ceph-create-keys -i $HOST' from 05_systemd_use_systemctl.patch
* Fri Oct 31 2014 osynge@suse.com
- Upgraded to 1.5.19
  + Create temporary ceph.conf files in ``/etc/ceph`` to avoid issues with
    SELinux.
  + Fix issue for enabling the OSD service in el-like distros.
  + Create a monitor keyring if it doesn't exist.
  + Do not ask twice for passwords when calling ``new``.
  + Ensure priorities are installed and enforced for custom repositories.
  + Enable services on ``el`` distros when deploying Ceph daemons.
  + Smarter detection of ``sudo`` need on remote nodes (prevents issues when
    running ceph-deploy as ``root`` or with ``sudo``.
  + Fix an issue where Debian Sid would break ceph-deploy failing Distro
    detection.
  + If ``wget`` is installed don't try to install it regardless.
  + Do not override environment variables on remote hosts, preserve them and
    extend the ``$PATH`` if not explicitly told not to.
  + Fix missing priority plugin in YUM for Fedora when installing
  + Implement --public-network and --cluster-network with remote IP validation
  + Fixed an issue where errors before the logger was setup would be silenced.
* Fri Sep  5 2014 osynge@suse.com
- Improved 05_systemd_use_systemctl.patch to enable mon daemon.
  + Fixes: bnc#893810
- Renamed patches:
  + calamari-suse.patch to 04_calamari-suse.patch
  + 04_systemctl.patch to 05_systemd_use_systemctl.patch
* Tue Sep  2 2014 osynge@suse.com
- Added patch to start mon deamons via systemd and setup keys
* Thu Aug 28 2014 osynge@suse.com
- Updated to ceph-deploy-1.5.12
  + Better traceback reporting with logging.
  + Close stderr/stdout when ceph-deploy completes operations (silences odd tracebacks)
  + Allow to re-use a ceph.conf file with --ceph-conf global flag
  + Be able to concatenate and seed keyring files with --keyrings
  + Fix a problem where CentOS7 is not matched correctly against repos (Thanks Tom Walsh)
* Tue Aug 19 2014 tserong@suse.com
- Support `ceph-deploy calamari` on SLES (no special calamari-minions
  repo, just relies on repos already being set up correctly on all hosts)
  + Added calamari-suse.patch
* Tue Aug  5 2014 osynge@suse.com
- Updated to ceph-deploy-1.5.10
  + Removed 2 patches
  - 01_ceph_deploy_zap_disk.patch now redundent.
  - 03_suse_zypper_not_yum.patch merged upstream.
  - renamed and renmbered patches.
  + Use ``ceph-disk`` with high verbosity
  + Use ``ceph-disk zap`` instead of re-implementing it
  + Use proper paths for ``zypper``
  + Allow to install repo files only
  + Work with inconsistent repo sections for Emperor when setting priorities
* Wed Jul 30 2014 osynge@suse.com
- Added patch 05_dev_or_dir.patch
  + ceph-disk should use "--data-dev" and "--data-dir" parameters.
  + added unit tests for detecting if directory or block device.
* Thu Jul 24 2014 osynge@suse.com
- Add patch to say SLE 12 and openSUSE 13.1 are sysv
* Mon Jul 21 2014 osynge@suse.com
- Updated to ceph-deploy-1.5.9
  + Allow to optionally set the ``fsid`` when calling ``new``
  + Correctly select sysvinit or systemd for Suse versions (Thanks Owen Synge)
  + Use correct version of remoto (``0.0.19``) that holds the ``None`` global fix
  + Fix new naming scheme for CentOS platforms that prevented CentOS 7 installs
* Mon Jul 14 2014 osynge@suse.com
- Fix: Specifying custom repos was failing bnc#886872
  + Patch suse_zypper_not_yum.patch
- Updated source to ceph-deploy-1.5.8
  + Create a flake8/pep8/linting job so that we prevent Undefined errors
  + Add partprobe/partx calls when zapping disks
  + Fix RHEL7 installation issues (url was using el6 incorrectly) (Thanks David Vossel)
  + Warn when an executable is not found
  + Fix an ``AttributeError`` in execnet (see https://github.com/alfredodeza/execnet/issues/1)
* Wed Jul  9 2014 osynge@suse.com
- Made python-remoto a BuildRequires as test suite should be effected.
* Fri Jul  4 2014 osynge@suse.com
- Removed bundled remoto into a seperate package.
* Fri Jul  4 2014 osynge@suse.com
- Updated to ceph-deploy-1.5.7
  + Fix NameError on osd.py from an undefined variable
  + Fix a calamari connect problem installing on multiple hosts
  + Optionally avoid vendoring libraries for upstream package
    maintainers.
- Added CEPH_DEPLOY_NO_VENDOR=no to setup.py to prevent setup.py
    workaround checking out master branch of remoto.
- Patched so default is not to add repos.
- Patched to require url for repo if adding a repo.
* Wed Jun 25 2014 lmb@suse.com
- Added ceph-deploy-zap-disk.diff
  + Fix sgdisk invocation to correctly zap disks
* Fri Jun 13 2014 osynge@suse.com
- Patched no_upstream_ceph_repos.patch
  + removes dependency on ceph.com repositories.
* Fri Jun 13 2014 osynge@suse.com
- Updated to ceph-deploy-1.5.5
  + Normalize repo file header calls. Fixes breakage on Calamari repos.
  + Improve help by adding online doc link
  + allow cephdeploy.conf to set priorities in repos
  + install priorities plugin for yum distros
  + set the right priority for ceph.repo and warn about this
  + Another fix for IPV6: write correct mon_host in ceph.conf
  + Support proxy settings for repo files in YUM
  + Better error message when ceph.conf is not found
  + Refuse to install custom cluster names on sysvinit systems (not supported)
  + Remove quiet flags from package manager\u2019s install calls to avoid timing out
  + Use the correct URL repo when installing for RHEL
  + Remove -- from the command to install packages. (Thanks Vincenzo Pii)
  + Default to Firefly as the latest, stable Ceph version
- Updated to remoto-0.0.16
  + spit stdout before stderr as errors should be read last
- Delete remoto from source code if it already exists.
* Fri May  2 2014 ddiss@suse.com
- Update to ceph-deploy-1.5.1
  + Fixes a broken osd command that had the wrong attribute in the conn object
- Update to ceph-deploy-1.5.0
  + Warn if requiretty is causing issues
  + Support IPV6 host resolution (Thanks Frode Nordahl)
  + Fix incorrect paths for local cephdeploy.conf
  + Support subcommand overrides defined in cephdeploy.conf
  + When installing on CentOS/RHEL call yum clean all
  + Check OSD status when deploying to catch possible issues
  + Add a --local-mirror flag for installation that syncs files
  + Implement osd list to list remote osds
  + Fix install issues on SUSE (Thanks Owen Synge)
* Tue Apr  1 2014 ddiss@suse.com
- Update to ceph-deploy-1.4.0
  + uninstall ceph-release and clean cache in CentOS
  + Add ability to add monitors to an existing cluster
  + Deprecate use of --stable for releases, introduce --release
  + Eat some tracebacks that may appear when closing remote connections
  + Enable default ceph-deploy configurations for repo handling
  + Fix wrong URL for rpm installs with --testing flag
- Update to ceph-deploy-1.3.5
  + Support Debian SID for installs
  + Error nicely when hosts cannot be resolved
  + Return a non-zero exit status when monitors have not formed quorum
  + Use the new upstream library for remote connections (execnet 1.2)
  + Ensure proper read permissions for ceph.conf when pushing configs
  + clean up color logging for non-tty sessions
  + do not reformat configs when pushing, pushes are now as-is
  + remove dry-run flag that did nothing
- Update to remoto-0.0.15
* Wed Feb  5 2014 ddiss@suse.com
- Update to ceph-deploy-1.3.4
- Update to remoto-0.0.12
* Thu Oct 10 2013 ddiss@suse.com
- Add missing python-setuptools runtime requires
* Thu Oct 10 2013 ddiss@suse.com
- Update to ceph-deploy-1.2.7
  + Rebase against upstream spec file.
  + Build tests unconditionally.
  + Bundle remoto-0.0.5 tarball, instead of git cloning during setup.
* Mon Jul 15 2013 speilicke@suse.com
- Allow running testssuite with build-conditional "tests"
* Mon Jul 15 2013 speilicke@suse.com
- Initial version
